@@ -3,7 +3,7 @@
 
 #include <string>
 #include <tr1/memory>
-#include <pcrecpp.h>
+#include "regex.h"
 
 /* This file contains prettynames and icons for well-known applications, that by default has no .desktop entry */
 
@@ -17,13 +17,11 @@ struct PrettyTableItem
 
 /* The current table is only a test */
 static const PrettyTableItem default_table[] = {
-	ITEM("(ba|z|tc|c|k)sh", "utilities-terminal"),
+	ITEM("(ba|z|tc|c|k)?sh", "utilities-terminal"),
 	ITEM("(k|sys|u)logd|logger", "internet-news-reader"),
 	ITEM("X(org)?", "display"),
-	ITEM("(ksoftirqd|aio|events|kondemand|reiserfs|kswapd|kblockd)/?\\d+", "applications-system"),
-	ITEM("kthread|khelper|khubd|kfand|ksuspend_usbd|pdflush", "applications-system"),
 	ITEM("apache2?|httpd|lighttpd", "internet-web-browser"),
-	ITEM("applet(-?2)?", "gnome-applets"),
+	ITEM(".*applet(-?2)?", "gnome-applets"),
 	ITEM("atd|cron|CRON|ntpd", "date"),
 	ITEM("cupsd|lpd?", "printer"),
 	ITEM("cvsd|mtn|git|svn", "file-manager"),
