@@ -177,7 +177,8 @@ static double get_relative_time(void)
 
 
 void
-procman_debug(const char *format, ...)
+procman_debug_real(const char *file, int line, const char *func,
+		   const char *format, ...)
 {
 	va_list args;
 	char *msg;
@@ -189,7 +190,7 @@ procman_debug(const char *format, ...)
 	msg = g_strdup_vprintf(format, args);
 	va_end(args);
 
-	g_debug("[%0.6f] %s", get_relative_time(), msg);
+	g_debug("[%.3f %s:%d %s] %s", get_relative_time(), file, line, func, msg);
 
 	g_free(msg);
 }
@@ -198,12 +199,31 @@ procman_debug(const char *format, ...)
 
 namespace procman
 {
-  void size_cell_data_func(GtkTreeViewColumn *col, GtkCellRenderer *renderer,
+  void size_cell_data_func(GtkTreeViewColumn *, GtkCellRenderer *renderer,
 			   GtkTreeModel *model, GtkTreeIter *iter,
 			   gpointer user_data)
   {
+    const guint index = GPOINTER_TO_UINT(user_data);
+
     guint64 size;
-    gtk_tree_model_get(model, iter, GPOINTER_TO_UINT(user_data), &size, -1);
+    GValue value = { 0 };
+
+    gtk_tree_model_get_value(model, iter, index, &value);
+
+    switch (G_VALUE_TYPE(&value)) {
+    case G_TYPE_ULONG:
+      size = g_value_get_ulong(&value);
+      break;
+
+    case G_TYPE_UINT64:
+      size = g_value_get_uint64(&value);
+      break;
+
+    default:
+      g_assert_not_reached();
+    }
+
+    g_value_unset(&value);
 
     char *str = SI_gnome_vfs_format_file_size_for_display(size);
     g_object_set(renderer, "text", str, NULL);
